==> doksan-0.2.tar.gz: doksan-0.2/doksan/variables.py <==
#!/usr/bin/env python

variables = {
	"tr": { 
		"_l_name":"https://www.scorespro.com/soccer/turkey/super-lig/",
		"_l_name_r":"https://www.scorespro.com/soccer/turkey/super-lig/results/",
		"_l_name_f":"https://www.scorespro.com/soccer/turkey/super-lig/fixtures/",
		"_l_name_t":"https://www.scorespro.com/soccer/turkey/super-lig/standings/",
		"adanademir":"https://www.scorespro.com/soccer/turkey/teams/adana-demirspor-MzA5ODg=/",
		"alanyaspor":"https://www.scorespro.com/soccer/turkey/teams/alanyaspor-MjUwNzE=/",
		"altay":"https://www.scorespro.com/soccer/turkey/teams/altay-MjIxMjA=/",
		"antalyaspor":"https://www.scorespro.com/soccer/turkey/teams/antalyaspor-MTMwMTk=/",
		"besiktas":"https://www.scorespro.com/soccer/turkey/teams/besiktas-MjM1NDM=/",
		"karagumruk":"https://www.scorespro.com/soccer/turkey/teams/f-karagumruk-MjIxMjU=/",
		"fenerbahce":"https://www.scorespro.com/soccer/turkey/teams/fenerbahce-MTMwMjQ=/",
		"galatasaray":"https://www.scorespro.com/soccer/turkey/teams/galatasaray-MjM1NTM=/",
		"gaziantep":"https://www.scorespro.com/soccer/turkey/teams/gaziantep-bb-MjA1NTQ=/",
		"giresun":"https://www.scorespro.com/soccer/turkey/teams/giresunspor-MjUwNzU=/",
		"goztepe":"https://www.scorespro.com/soccer/turkey/teams/goztepe-MTI4ODM=/",
		"hatayspor":"https://www.scorespro.com/soccer/turkey/teams/hatayspor-MzEwNzI=/",
		"basaksehir":"https://www.scorespro.com/soccer/turkey/teams/istanbul-bb-MjIxMTg=/",
		"kasimpasa":"https://www.scorespro.com/soccer/turkey/teams/kasimpasa-MjUwNzM=/",
		"kayserispor":"https://www.scorespro.com/soccer/turkey/teams/kayserispor-MTMwMTI=/",
		"konyaspor":"https://www.scorespro.com/soccer/turkey/teams/konyaspor-MzEwOQ==/",
		"goztepe":"https://www.scorespro.com/soccer/turkey/teams/goztepe-MTI4ODM=/",
		"rizespor":"https://www.scorespro.com/soccer/turkey/teams/rizespor-MTI4MzY=/",
		"sivasspor":"https://www.scorespro.com/soccer/turkey/teams/sivasspor-MjIxMTM=/",
		"trabzonspor":"https://www.scorespro.com/soccer/turkey/teams/trabzonspor-MTI5OTY=/",
		"yenimalatya":"https://www.scorespro.com/soccer/turkey/teams/yeni-malatyaspor-MzI4MTc=/"
	},
	"en": {
		"_l_name":"https://www.scorespro.com/soccer/england/premier-league/",
		"_l_name_r":"https://www.scorespro.com/soccer/england/premier-league/results/",
		"_l_name_f":"https://www.scorespro.com/soccer/england/premier-league/fixtures/",
		"_l_name_t":"https://www.scorespro.com/soccer/england/premier-league/standings/",
		"arsenal": "https://www.scorespro.com/soccer/england/teams/arsenal-fc-MTE1NzM=/",
		"astonvilla": "https://www.scorespro.com/soccer/england/teams/aston-villa-NTI1OQ==/",
		"brentford": "https://www.scorespro.com/soccer/england/teams/brentford-fc-MTE3MTU=/",
		"brighton": "https://www.scorespro.com/soccer/england/teams/brighton-MjQ2Mg==/",
		"burnley": "https://www.scorespro.com/soccer/england/teams/burnley-fc-MTA4MzQ=/",
		"chelsea": "https://www.scorespro.com/soccer/england/teams/chelsea-fc-MjQyMA==/",
		"crystalpalace": "https://www.scorespro.com/soccer/england/teams/crystal-palace-MTA4Mzc=/",
		"everton": "https://www.scorespro.com/soccer/england/teams/everton-fc-MTA4MTg=/",
		"leeds": "https://www.scorespro.com/soccer/england/teams/leeds-united-NDY4Mw==/",
		"leicester": "https://www.scorespro.com/soccer/england/teams/leicester-city-MTA4MjI=/",
		"liverpool": "https://www.scorespro.com/soccer/england/teams/liverpool-fc-MTA5OTE=/",
		"manchestercity": "https://www.scorespro.com/soccer/england/teams/manchester-city-MTE2NzY=/",
		"manchesterunited": "https://www.scorespro.com/soccer/england/teams/manchester-united-MjQyNw==/",
		"newcastle": "https://www.scorespro.com/soccer/england/teams/newcastle-united-MTA4MjY=/",
		"norwich": "https://www.scorespro.com/soccer/england/teams/norwich-city-MjQ0NA==/",
		"southampton": "https://www.scorespro.com/soccer/england/teams/southampton-NTI3Mw==/",
		"tottenham": "https://www.scorespro.com/soccer/england/teams/tottenham-MjQzMg==/",
		"watford": "https://www.scorespro.com/soccer/england/teams/watford-fc-MTA4NTE=/",
		"westham": "https://www.scorespro.com/soccer/england/teams/west-ham-MTA4MzA=/",
		"wolves": "https://www.scorespro.com/soccer/england/teams/wolverhampton-wanderers-fc-MjQzMw==/"
	},
	"es": {
		"_l_name":"https://www.scorespro.com/soccer/spain/laliga/",
		"_l_name_r":"https://www.scorespro.com/soccer/spain/laliga/results/",
		"_l_name_f":"https://www.scorespro.com/soccer/spain/laliga/fixtures/",
		"_l_name_t":"https://www.scorespro.com/soccer/spain/laliga/standings/",
		"alaves":"https://www.scorespro.com/soccer/spain/teams/deportivo-alaves-MTc4MjQ=/",
		"bilbao":"https://www.scorespro.com/soccer/spain/teams/athletic-bilbao-MTgwMTk=/",
		"atleticomadrid":"https://www.scorespro.com/soccer/spain/teams/atletico-madrid-MTgwNjM=/",
		"barcelona":"https://www.scorespro.com/soccer/spain/teams/fc-barcelona-MTc3NjI=/",
		"cadiz":"https://www.scorespro.com/soccer/spain/teams/cadiz-MTc4MDM=/",
		"celtavigo":"https://www.scorespro.com/soccer/spain/teams/celta-vigo-NDE3Mg==/",
		"elche":"https://www.scorespro.com/soccer/spain/teams/elche-MTc3ODc=/",
		"espanyol":"https://www.scorespro.com/soccer/spain/teams/real-cd-espanyol-NDE3Mw==/",
		"getafe":"https://www.scorespro.com/soccer/spain/teams/getafe-MTc5MTk=/",
		"granada":"https://www.scorespro.com/soccer/spain/teams/granada-cf-Mzc4MDE=/",
		"levante":"https://www.scorespro.com/soccer/spain/teams/levante-MTgwNTI=/",
		"mallorca":"https://www.scorespro.com/soccer/spain/teams/mallorca-MTgwNTQ=/",
		"osasuna":"https://www.scorespro.com/soccer/spain/teams/osasuna-NDE3OA==/",
		"rayovallecano":"https://www.scorespro.com/soccer/spain/teams/rayo-vallecano-MjUxOTc=/",
		"realbetis":"https://www.scorespro.com/soccer/spain/teams/real-betis-MTgwMjI=/",
		"realmadrid":"https://www.scorespro.com/soccer/spain/teams/real-madrid-NDE4MA==/",
		"realsociedad":"https://www.scorespro.com/soccer/spain/teams/real-sociedad-MTgwMzI=/",
		"sevilla":"https://www.scorespro.com/soccer/spain/teams/sevilla-MjYyNTM=/",
		"valencia":"https://www.scorespro.com/soccer/spain/teams/valencia-MTgwMzc=/",
		"villareal":"https://www.scorespro.com/soccer/spain/teams/villarreal-MTc4NDI=/"
	}
}

==> doksan-0.2.2.tar.gz: doksan-0.2.2/doksan/variables.py <==
#!/usr/bin/env python

variables = {
	"tr": { 
		"_l_name":"https://www.scorespro.com/soccer/turkey/super-lig/",
		"_l_name_r":"https://www.scorespro.com/soccer/turkey/super-lig/results/",
		"_l_name_f":"https://www.scorespro.com/soccer/turkey/super-lig/fixtures/",
		"_l_name_t":"https://www.scorespro.com/soccer/turkey/super-lig/standings/",
		"adanademir":"https://www.scorespro.com/soccer/turkey/teams/adana-demirspor-MzA5ODg=/",
		"alanyaspor":"https://www.scorespro.com/soccer/turkey/teams/alanyaspor-MjUwNzE=/",
		"altay":"https://www.scorespro.com/soccer/turkey/teams/altay-MjIxMjA=/",
		"antalyaspor":"https://www.scorespro.com/soccer/turkey/teams/antalyaspor-MTMwMTk=/",
		"besiktas":"https://www.scorespro.com/soccer/turkey/teams/besiktas-MjM1NDM=/",
		"karagumruk":"https://www.scorespro.com/soccer/turkey/teams/f-karagumruk-MjIxMjU=/",
		"fenerbahce":"https://www.scorespro.com/soccer/turkey/teams/fenerbahce-MTMwMjQ=/",
		"galatasaray":"https://www.scorespro.com/soccer/turkey/teams/galatasaray-MjM1NTM=/",
		"gaziantep":"https://www.scorespro.com/soccer/turkey/teams/gaziantep-bb-MjA1NTQ=/",
		"giresun":"https://www.scorespro.com/soccer/turkey/teams/giresunspor-MjUwNzU=/",
		"goztepe":"https://www.scorespro.com/soccer/turkey/teams/goztepe-MTI4ODM=/",
		"hatayspor":"https://www.scorespro.com/soccer/turkey/teams/hatayspor-MzEwNzI=/",
		"basaksehir":"https://www.scorespro.com/soccer/turkey/teams/istanbul-bb-MjIxMTg=/",
		"kasimpasa":"https://www.scorespro.com/soccer/turkey/teams/kasimpasa-MjUwNzM=/",
		"kayserispor":"https://www.scorespro.com/soccer/turkey/teams/kayserispor-MTMwMTI=/",
		"konyaspor":"https://www.scorespro.com/soccer/turkey/teams/konyaspor-MzEwOQ==/",
		"goztepe":"https://www.scorespro.com/soccer/turkey/teams/goztepe-MTI4ODM=/",
		"rizespor":"https://www.scorespro.com/soccer/turkey/teams/rizespor-MTI4MzY=/",
		"sivasspor":"https://www.scorespro.com/soccer/turkey/teams/sivasspor-MjIxMTM=/",
		"trabzonspor":"https://www.scorespro.com/soccer/turkey/teams/trabzonspor-MTI5OTY=/",
		"yenimalatya":"https://www.scorespro.com/soccer/turkey/teams/yeni-malatyaspor-MzI4MTc=/"
	},
	"en": {
		"_l_name":"https://www.livescores.com/football/england/premier-league/",
		"arsenal": "Arsenal",
		"astonvilla": "Aston Villa",
		"brentford": "Brentford",
		"brighton": "Brighton & Hove Albion",
		"bournemouth": "AFC Bournemouth",
		"forest": "Nottingham Forest",
		"fulham": "Fulham",
		"chelsea": "Chelsea",
		"crystalpalace": "Crystal Palace",
		"everton": "Everton",
		"leeds": "Leeds United",
		"leicester": "Leicester City",
		"liverpool": "Liverpool",
		"manchestercity": "Manchester City",
		"manchesterunited": "Manchester United",
		"newcastle": "Newcastle United",
		"southampton": "Southampton",
		"tottenham": "Tottenham Hotspur",
		"westham": "West Ham United",
		"wolves": "Wolverhampton Wanderers"
	},
	"es": {
		"_l_name":"https://www.scorespro.com/soccer/spain/laliga/",
		"_l_name_r":"https://www.scorespro.com/soccer/spain/laliga/results/",
		"_l_name_f":"https://www.scorespro.com/soccer/spain/laliga/fixtures/",
		"_l_name_t":"https://www.scorespro.com/soccer/spain/laliga/standings/",
		"alaves":"https://www.scorespro.com/soccer/spain/teams/deportivo-alaves-MTc4MjQ=/",
		"bilbao":"https://www.scorespro.com/soccer/spain/teams/athletic-bilbao-MTgwMTk=/",
		"atleticomadrid":"https://www.scorespro.com/soccer/spain/teams/atletico-madrid-MTgwNjM=/",
		"barcelona":"https://www.scorespro.com/soccer/spain/teams/fc-barcelona-MTc3NjI=/",
		"cadiz":"https://www.scorespro.com/soccer/spain/teams/cadiz-MTc4MDM=/",
		"celtavigo":"https://www.scorespro.com/soccer/spain/teams/celta-vigo-NDE3Mg==/",
		"elche":"https://www.scorespro.com/soccer/spain/teams/elche-MTc3ODc=/",
		"espanyol":"https://www.scorespro.com/soccer/spain/teams/real-cd-espanyol-NDE3Mw==/",
		"getafe":"https://www.scorespro.com/soccer/spain/teams/getafe-MTc5MTk=/",
		"granada":"https://www.scorespro.com/soccer/spain/teams/granada-cf-Mzc4MDE=/",
		"levante":"https://www.scorespro.com/soccer/spain/teams/levante-MTgwNTI=/",
		"mallorca":"https://www.scorespro.com/soccer/spain/teams/mallorca-MTgwNTQ=/",
		"osasuna":"https://www.scorespro.com/soccer/spain/teams/osasuna-NDE3OA==/",
		"rayovallecano":"https://www.scorespro.com/soccer/spain/teams/rayo-vallecano-MjUxOTc=/",
		"realbetis":"https://www.scorespro.com/soccer/spain/teams/real-betis-MTgwMjI=/",
		"realmadrid":"https://www.scorespro.com/soccer/spain/teams/real-madrid-NDE4MA==/",
		"realsociedad":"https://www.scorespro.com/soccer/spain/teams/real-sociedad-MTgwMzI=/",
		"sevilla":"https://www.scorespro.com/soccer/spain/teams/sevilla-MjYyNTM=/",
		"valencia":"https://www.scorespro.com/soccer/spain/teams/valencia-MTgwMzc=/",
		"villareal":"https://www.scorespro.com/soccer/spain/teams/villarreal-MTc4NDI=/"
	}
}
